@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -41,11 +42,7 @@
 #include <editeng/brshitem.hxx>
 #include <editeng/splwrap.hxx>
 #include <editeng/pgrditem.hxx>
-// --> OD 2008-01-17 #newlistlevelattrs#
-#ifndef _SVX_TSTPITEM_HXX
 #include <editeng/tstpitem.hxx>
-#endif
-// <--
 
 #include <SwSmartTagMgr.hxx>
 #include <linguistic/lngprops.hxx>
@@ -61,9 +58,7 @@
 #include <viewopt.hxx>	// SwViewOptions
 #include <frmtool.hxx>	// DrawGraphic
 #include <IDocumentSettingAccess.hxx>
-#ifndef IDOCUMENTDEVICEACCESS_HXX_INCLUDED
 #include <IDocumentDeviceAccess.hxx>
-#endif
 #include <paratr.hxx>	// SwFmtDrop
 #include <rootfrm.hxx>  // SwRootFrm
 #include <inftxt.hxx>	// SwTxtInfo
@@ -107,7 +102,7 @@ using namespace ::com::sun::star::beans;
 
 // --> OD 2006-06-27 #b6440955#
 // variable moved to class <numfunc:GetDefBulletConfig>
-//extern const sal_Char __FAR_DATA sBulletFntName[];
+//extern const sal_Char sBulletFntName[];
 namespace numfunc
 {
     extern const String& GetDefBulletFontname();
@@ -115,43 +110,30 @@ namespace numfunc
 }
 // <--
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 // Test2: WYSIWYG++
 // Test4: WYSIWYG debug
 static sal_Bool bDbgLow = sal_False;
 #endif
 
-#ifdef DBG_UTIL
-
+#if OSL_DEBUG_LEVEL > 1
 sal_Bool SwTxtSizeInfo::IsOptCalm() const { return !GetOpt().IsTest3(); }
-
 sal_Bool SwTxtSizeInfo::IsOptLow() const { return bDbgLow; }
-
 sal_Bool SwTxtSizeInfo::IsOptDbg() const { return GetOpt().IsTest4(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest1() const { return GetOpt().IsTest1(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest2() const { return GetOpt().IsTest2(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest3() const { return GetOpt().IsTest3(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest4() const { return GetOpt().IsTest4(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest5() const { return GetOpt().IsTest5(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest6() const { return GetOpt().IsTest6(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest7() const { return GetOpt().IsTest7(); }
-
 sal_Bool SwTxtSizeInfo::IsOptTest8() const { return GetOpt().IsTest8(); }
-
 #endif
 
 /*************************************************************************
  *						SwLineInfo::SwLineInfo()
  *************************************************************************/
 
-// --> OD 2008-01-17 #newlistlevelattrs#
 SwLineInfo::SwLineInfo()
     : pRuler( 0 ),
       pSpace( 0 ),
@@ -168,10 +150,7 @@ SwLineInfo::~SwLineInfo()
 }
 void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
                                    const SwTxtNode& rTxtNode )
-// <--
 {
-    // --> OD 2008-01-17 #newlistlevelattrs#
-//    pRuler = &rAttrSet.GetTabStops();
     delete pRuler;
     pRuler = new SvxTabStopItem( rAttrSet.GetTabStops() );
     if ( rTxtNode.GetListTabStopPosition( nListTabStopPosition ) )
@@ -184,7 +163,7 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
         pRuler->Insert( aListTabStop );
 
         // remove default tab stops, which are before the inserted list tab stop
-        for ( USHORT i = 0; i < pRuler->Count(); i++ )
+        for ( sal_uInt16 i = 0; i < pRuler->Count(); i++ )
         {
             if ( (*pRuler)[i].GetTabPos() < nListTabStopPosition &&
                  (*pRuler)[i].GetAdjustment() == SVX_TAB_ADJUST_DEFAULT )
@@ -194,12 +173,11 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
             }
         }
     }
-    // <--
-    // --> OD 2008-02-15 #newlistlevelattrs#
+
     if ( !rTxtNode.getIDocumentSettingAccess()->get(IDocumentSettingAccess::TABS_RELATIVE_TO_INDENT) )
     {
         // remove default tab stop at position 0
-        for ( USHORT i = 0; i < pRuler->Count(); i++ )
+        for ( sal_uInt16 i = 0; i < pRuler->Count(); i++ )
         {
             if ( (*pRuler)[i].GetTabPos() == 0 &&
                  (*pRuler)[i].GetAdjustment() == SVX_TAB_ADJUST_DEFAULT )
@@ -209,7 +187,7 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
             }
         }
     }
-    // <--
+
     pSpace = &rAttrSet.GetLineSpacing();
     nVertAlign = rAttrSet.GetParaVertAlign().GetValue();
     nDefTabStop = MSHRT_MAX;
@@ -225,7 +203,7 @@ void SwTxtInfo::CtorInitTxtInfo( SwTxtFrm *pFrm )
     nTxtStart = pFrm->GetOfst();
     if( !pPara )
     {
-        ASSERT( pPara, "+SwTxtInfo::CTOR: missing paragraph information" );
+        OSL_ENSURE( pPara, "+SwTxtInfo::CTOR: missing paragraph information" );
         pFrm->Format();
         pPara = pFrm->GetPara();
     }
@@ -237,7 +215,7 @@ SwTxtInfo::SwTxtInfo( const SwTxtInfo &rInf )
 { }
 
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 /*************************************************************************
  *						ChkOutDev()
  *************************************************************************/
@@ -249,7 +227,7 @@ void ChkOutDev( const SwTxtSizeInfo &rInf )
 
     const OutputDevice* pOut = rInf.GetOut();
     const OutputDevice* pRef = rInf.GetRefDev();
-    ASSERT( pOut && pRef, "ChkOutDev: invalid output devices" )
+    OSL_ENSURE( pOut && pRef, "ChkOutDev: invalid output devices" );
 }
 #endif	// PRODUCT
 
@@ -290,7 +268,7 @@ SwTxtSizeInfo::SwTxtSizeInfo( const SwTxtSizeInfo &rNew )
       bSnapToGrid( rNew.SnapToGrid() ),
       nDirection( rNew.GetDirection() )
 {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     ChkOutDev( *this );
 #endif
 }
@@ -303,7 +281,7 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
     pFrm = pFrame;
     CtorInitTxtInfo( pFrm );
     const SwTxtNode *pNd = pFrm->GetTxtNode();
-    pVsh = pFrm->GetShell();
+    pVsh = pFrm->getRootFrm()->GetCurrShell();
 
     // Get the output and reference device
     if ( pVsh )
@@ -315,7 +293,7 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
     else
     {
         //Zugriff ueber StarONE, es muss keine Shell existieren oder aktiv sein.
-        if ( pNd->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) )
+        if ( pNd->getIDocumentSettingAccess()->get(IDocumentSettingAccess::HTML_MODE) )
         {
             //in Ermangelung eines Besseren kann hier ja wohl nur noch das
             //AppWin genommen werden?
@@ -327,7 +305,7 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
         pRef = pOut;
     }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     ChkOutDev( *this );
 #endif
 
@@ -345,18 +323,6 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
         nDirection = DIR_LEFT2RIGHT;
     }
 
-/*    LanguageType eLang;
-    const SvtCTLOptions& rCTLOptions = SW_MOD()->GetCTLOptions();
-    if ( SvtCTLOptions::NUMERALS_HINDI == rCTLOptions.GetCTLTextNumerals() )
-        eLang = LANGUAGE_ARABIC_SAUDI_ARABIA;
-    else if ( SvtCTLOptions::NUMERALS_ARABIC == rCTLOptions.GetCTLTextNumerals() )
-        eLang = LANGUAGE_ENGLISH;
-    else
-        eLang = (LanguageType)::GetAppLanguage();
-
-    pOut->SetDigitLanguage( eLang );
-    pRef->SetDigitLanguage( eLang );*/
-
     //
     // The Options
     //
@@ -415,7 +381,7 @@ SwTxtSizeInfo::SwTxtSizeInfo( const SwTxtSizeInfo &rNew, const XubString &rTxt,
       bSnapToGrid( rNew.SnapToGrid() ),
       nDirection( rNew.GetDirection() )
 {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     ChkOutDev( *this );
 #endif
     SetLen( GetMinLen( *this ) );
@@ -444,8 +410,8 @@ void SwTxtSizeInfo::NoteAnimation() const
     if( OnWin() )
         SwRootFrm::FlushVout();
 
-    ASSERT( pOut == pVsh->GetOut(),
-            "SwTxtSizeInfo::NoteAnimation() changed pOut" )
+    OSL_ENSURE( pOut == pVsh->GetOut(),
+            "SwTxtSizeInfo::NoteAnimation() changed pOut" );
 }
 
 /*************************************************************************
@@ -457,7 +423,7 @@ SwPosSize SwTxtSizeInfo::GetTxtSize( OutputDevice* pOutDev,
                                      const XubString& rTxt,
                                      const xub_StrLen nIndex,
                                      const xub_StrLen nLength,
-                                     const USHORT nComp ) const
+                                     const sal_uInt16 nComp ) const
 {
     SwDrawTextInfo aDrawInf( pVsh, *pOutDev, pSI, rTxt, nIndex, nLength );
     aDrawInf.SetFrm( pFrm );
@@ -479,7 +445,7 @@ SwPosSize SwTxtSizeInfo::GetTxtSize() const
 
     // in some cases, compression is not allowed or surpressed for
     // performance reasons
-    USHORT nComp =( SW_CJK == GetFont()->GetActual() &&
+    sal_uInt16 nComp =( SW_CJK == GetFont()->GetActual() &&
                     rSI.CountCompChg() &&
                     ! IsMulti() ) ?
                     GetKanaComp() :
@@ -498,8 +464,8 @@ SwPosSize SwTxtSizeInfo::GetTxtSize() const
  *************************************************************************/
 
 void SwTxtSizeInfo::GetTxtSize( const SwScriptInfo* pSI, const xub_StrLen nIndex,
-                                const xub_StrLen nLength, const USHORT nComp,
-                                USHORT& nMinSize, USHORT& nMaxSizeDiff ) const
+                                const xub_StrLen nLength, const sal_uInt16 nComp,
+                                sal_uInt16& nMinSize, sal_uInt16& nMaxSizeDiff ) const
 {
     SwDrawTextInfo aDrawInf( pVsh, *pOut, pSI, *pTxt, nIndex, nLength );
     aDrawInf.SetFrm( pFrm );
@@ -507,7 +473,7 @@ void SwTxtSizeInfo::GetTxtSize( const SwScriptInfo* pSI, const xub_StrLen nIndex
     aDrawInf.SetSnapToGrid( SnapToGrid() );
     aDrawInf.SetKanaComp( nComp );
     SwPosSize aSize = pFnt->_GetTxtSize( aDrawInf );
-    nMaxSizeDiff = (USHORT)aDrawInf.GetKanaDiff();
+    nMaxSizeDiff = (sal_uInt16)aDrawInf.GetKanaDiff();
     nMinSize = aSize.Width();
 }
 
@@ -517,12 +483,12 @@ void SwTxtSizeInfo::GetTxtSize( const SwScriptInfo* pSI, const xub_StrLen nIndex
 
 xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
                                        const xub_StrLen nMaxLen,
-                                       const USHORT nComp ) const
+                                       const sal_uInt16 nComp ) const
 {
     const SwScriptInfo& rScriptInfo =
                      ( (SwParaPortion*)GetParaPortion() )->GetScriptInfo();
 
-    ASSERT( pRef == pOut, "GetTxtBreak is supposed to use the RefDev" )
+    OSL_ENSURE( pRef == pOut, "GetTxtBreak is supposed to use the RefDev" );
     SwDrawTextInfo aDrawInf( pVsh, *pOut, &rScriptInfo,
                              *pTxt, GetIdx(), nMaxLen );
     aDrawInf.SetFrm( pFrm );
@@ -540,13 +506,13 @@ xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
 
 xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
                                        const xub_StrLen nMaxLen,
-                                       const USHORT nComp,
+                                       const sal_uInt16 nComp,
                                        xub_StrLen& rExtraCharPos ) const
 {
     const SwScriptInfo& rScriptInfo =
                      ( (SwParaPortion*)GetParaPortion() )->GetScriptInfo();
 
-    ASSERT( pRef == pOut, "GetTxtBreak is supposed to use the RefDev" )
+    OSL_ENSURE( pRef == pOut, "GetTxtBreak is supposed to use the RefDev" );
     SwDrawTextInfo aDrawInf( pVsh, *pOut, &rScriptInfo,
                              *pTxt, GetIdx(), nMaxLen );
     aDrawInf.SetFrm( pFrm );
@@ -573,10 +539,10 @@ void SwTxtPaintInfo::CtorInitTxtPaintInfo( SwTxtFrm *pFrame, const SwRect &rPain
     pGrammarCheckList = NULL;
     pSmartTags = NULL;  // SMARTTAGS
 
-#ifndef DBG_UTIL
-    pBrushItem = 0;
-#else
+#if OSL_DEBUG_LEVEL > 1
     pBrushItem = ((SvxBrushItem*)-1);
+#else
+    pBrushItem = 0;
 #endif
 }
 
@@ -628,7 +594,7 @@ sal_Bool lcl_IsDarkBackground( const SwTxtPaintInfo& rInf )
         /// OD 21.08.2002 #99657#
         ///     There is a background color, if there is a background brush and
         ///     its color is *not* "no fill"/"auto fill".
-        if( rInf.GetTxtFrm()->GetBackgroundBrush( pItem, pCol, aOrigBackRect, FALSE ) )
+        if( rInf.GetTxtFrm()->GetBackgroundBrush( pItem, pCol, aOrigBackRect, sal_False ) )
         {
             if ( !pCol )
                 pCol = &pItem->GetColor();
@@ -665,7 +631,7 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
     if( GetFont()->IsBlink() && OnWin() && rPor.Width() )
     {
         // check if accessibility options allow blinking portions:
-        const ViewShell* pSh = GetTxtFrm()->GetShell();
+        const ViewShell* pSh = GetTxtFrm()->getRootFrm()->GetCurrShell();
         if ( pSh && ! pSh->GetAccessibilityOptions()->IsStopAnimatedText() &&
              ! pSh->IsPreView() )
         {
@@ -702,7 +668,7 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
 
     // in some cases, kana compression is not allowed or surpressed for
     // performance reasons
-    USHORT nComp = 0;
+    sal_uInt16 nComp = 0;
     if ( ! IsMulti() )
         nComp = GetKanaComp();
 
@@ -713,8 +679,8 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
     const sal_Bool bTmpGrammarCheck = bGrammarCheck && OnWin() && bCfgIsAutoGrammar && GetOpt().IsOnlineSpell();
     const sal_Bool bTmpSmart = bSmartTag && OnWin() && !GetOpt().IsPagePreview() && SwSmartTagMgr::Get().IsSmartTagsEnabled(); // SMARTTAGS
 
-    ASSERT( GetParaPortion(), "No paragraph!");
-    SwDrawTextInfo aDrawInf( pFrm->GetShell(), *pOut, pSI, rText, nStart, nLength,
+    OSL_ENSURE( GetParaPortion(), "No paragraph!");
+    SwDrawTextInfo aDrawInf( pFrm->getRootFrm()->GetCurrShell(), *pOut, pSI, rText, nStart, nLength,
                              rPor.Width(), bBullet );
 
     aDrawInf.SetLeft( GetPaintRect().Left() );
@@ -818,12 +784,16 @@ void SwTxtPaintInfo::CalcRect( const SwLinePortion& rPor,
     else
     {
         aPoint.A() = X();
-        aPoint.B() = Y() - rPor.GetAscent();
+        //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+        if ( GetTxtFrm()->IsVertLR() )
+            aPoint.B() = Y() - rPor.Height() + rPor.GetAscent();
+        else
+            aPoint.B() = Y() - rPor.GetAscent();
     }
 
     // Adjust x coordinate if we are inside a bidi portion
-    const BOOL bFrmDir = GetTxtFrm()->IsRightToLeft();
-    BOOL bCounterDir = ( ! bFrmDir && DIR_RIGHT2LEFT == GetDirection() ) ||
+    const sal_Bool bFrmDir = GetTxtFrm()->IsRightToLeft();
+    sal_Bool bCounterDir = ( ! bFrmDir && DIR_RIGHT2LEFT == GetDirection() ) ||
                        (   bFrmDir && DIR_LEFT2RIGHT == GetDirection() );
 
     if ( bCounterDir )
@@ -867,7 +837,7 @@ void SwTxtPaintInfo::CalcRect( const SwLinePortion& rPor,
 
 static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rPor,
                       SwRect& rRect, const Color* pCol, sal_Unicode cChar,
-                      BYTE nOptions )
+                      sal_uInt8 nOptions )
 {
     sal_Bool bCenter = 0 != ( nOptions & DRAW_SPECIAL_OPTIONS_CENTER );
     sal_Bool bRotate = 0 != ( nOptions & DRAW_SPECIAL_OPTIONS_ROTATE );
@@ -908,7 +878,7 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
     ((SwTxtPaintInfo&)rInf).SetFont( pFnt );
 
     // The maximum width depends on the current orientation
-    const USHORT nDir = pFnt->GetOrientation( rInf.GetTxtFrm()->IsVertical() );
+    const sal_uInt16 nDir = pFnt->GetOrientation( rInf.GetTxtFrm()->IsVertical() );
     SwTwips nMaxWidth = 0;
     switch ( nDir )
     {
@@ -920,7 +890,7 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
         nMaxWidth = rRect.Height();
         break;
     default:
-        ASSERT( sal_False, "Unknown direction set at font" )
+        OSL_FAIL( "Unknown direction set at font" );
         break;
     }
 
@@ -933,7 +903,7 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
         const SwTwips nOldWidth = aFontSize.Width();
 
         // new height for font
-        const BYTE nAct = pFnt->GetActual();
+        const sal_uInt8 nAct = pFnt->GetActual();
         aFontSize.Height() = ( 100 * pFnt->GetSize( nAct ).Height() ) / nFactor;
         aFontSize.Width() = ( 100 * pFnt->GetSize( nAct).Width() ) / nFactor;
 
@@ -974,8 +944,8 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
 
     Point aTmpPos( nX, nY );
     ((SwTxtPaintInfo&)rInf).SetPos( aTmpPos );
-    USHORT nOldWidth = rPor.Width();
-    ((SwLinePortion&)rPor).Width( (USHORT)aFontSize.Width() );
+    sal_uInt16 nOldWidth = rPor.Width();
+    ((SwLinePortion&)rPor).Width( (sal_uInt16)aFontSize.Width() );
     rInf.DrawText( aTmp, rPor );
     ((SwLinePortion&)rPor).Width( nOldWidth );
     ((SwTxtPaintInfo&)rInf).SetFont( (SwFont*)pOldFnt );
@@ -998,7 +968,7 @@ void SwTxtPaintInfo::DrawRect( const SwRect &rRect, sal_Bool bNoGraphic,
             pOut->DrawRect( rRect.SVRect() );
         else
         {
-            ASSERT( ((SvxBrushItem*)-1) != pBrushItem, "DrawRect: Uninitialized BrushItem!" );
+            OSL_ENSURE( ((SvxBrushItem*)-1) != pBrushItem, "DrawRect: Uninitialized BrushItem!" );
             ::DrawGraphic( pBrushItem, pOut, aItemRect, rRect );
         }
     }
@@ -1020,7 +990,7 @@ void SwTxtPaintInfo::DrawTab( const SwLinePortion &rPor ) const
 
         const sal_Unicode cChar = GetTxtFrm()->IsRightToLeft() ?
                                   CHAR_TAB_RTL : CHAR_TAB;
-        const BYTE nOptions = DRAW_SPECIAL_OPTIONS_CENTER |
+        const sal_uInt8 nOptions = DRAW_SPECIAL_OPTIONS_CENTER |
                               DRAW_SPECIAL_OPTIONS_ROTATE;
         lcl_DrawSpecial( *this, rPor, aRect, 0, cChar, nOptions );
     }
@@ -1044,7 +1014,7 @@ void SwTxtPaintInfo::DrawLineBreak( const SwLinePortion &rPor ) const
         {
             const sal_Unicode cChar = GetTxtFrm()->IsRightToLeft() ?
                                       CHAR_LINEBREAK_RTL : CHAR_LINEBREAK;
-            const BYTE nOptions = 0;
+            const sal_uInt8 nOptions = 0;
             lcl_DrawSpecial( *this, rPor, aRect, 0, cChar, nOptions );
         }
 
@@ -1086,7 +1056,7 @@ void SwTxtPaintInfo::DrawRedArrow( const SwLinePortion &rPor ) const
 
     if( aRect.HasArea() )
     {
-        const BYTE nOptions = 0;
+        const sal_uInt8 nOptions = 0;
         lcl_DrawSpecial( *this, rPor, aRect, &aCol, cChar, nOptions );
     }
 }
@@ -1103,9 +1073,9 @@ void SwTxtPaintInfo::DrawPostIts( const SwLinePortion&, sal_Bool bScript ) const
         Size aSize;
         Point aTmp;
 
-        const USHORT nPostItsWidth = pOpt->GetPostItsWidth( GetOut() );
-        const USHORT nFontHeight = pFnt->GetHeight( pVsh, *GetOut() );
-        const USHORT nFontAscent = pFnt->GetAscent( pVsh, *GetOut() );
+        const sal_uInt16 nPostItsWidth = pOpt->GetPostItsWidth( GetOut() );
+        const sal_uInt16 nFontHeight = pFnt->GetHeight( pVsh, *GetOut() );
+        const sal_uInt16 nFontAscent = pFnt->GetAscent( pVsh, *GetOut() );
 
         switch ( pFnt->GetOrientation( GetTxtFrm()->IsVertical() ) )
         {
@@ -1177,7 +1147,7 @@ void SwTxtPaintInfo::DrawCheckBox( const SwFieldFormPortion &rPor, bool checked)
  *************************************************************************/
 void SwTxtPaintInfo::DrawBackground( const SwLinePortion &rPor ) const
 {
-    ASSERT( OnWin(), "SwTxtPaintInfo::DrawBackground: printer polution ?" );
+    OSL_ENSURE( OnWin(), "SwTxtPaintInfo::DrawBackground: printer polution ?" );
 
     SwRect aIntersect;
     CalcRect( rPor, 0, &aIntersect );
@@ -1246,7 +1216,7 @@ void SwTxtPaintInfo::_DrawBackBrush( const SwLinePortion &rPor ) const
     }
     if( !pFnt->GetBackColor() ) return;
 
-    ASSERT( pFnt->GetBackColor(), "DrawBackBrush: Lost Color" );
+    OSL_ENSURE( pFnt->GetBackColor(), "DrawBackBrush: Lost Color" );
 
     SwRect aIntersect;
     CalcRect( rPor, 0, &aIntersect );
@@ -1304,7 +1274,7 @@ void SwTxtPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
             case POR_BLANK:     if ( GetOpt().IsHardBlank())bDraw = sal_True; break;
             default:
             {
-                ASSERT( !this, "SwTxtPaintInfo::DrawViewOpt: don't know how to draw this" );
+                OSL_ENSURE( !this, "SwTxtPaintInfo::DrawViewOpt: don't know how to draw this" );
                 break;
             }
         }
@@ -1319,7 +1289,7 @@ void SwTxtPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
 
 void SwTxtPaintInfo::_NotifyURL( const SwLinePortion &rPor ) const
 {
-    ASSERT( pNoteURL, "NotifyURL: pNoteURL gone with the wind!" );
+    OSL_ENSURE( pNoteURL, "NotifyURL: pNoteURL gone with the wind!" );
 
     SwRect aIntersect;
     CalcRect( rPor, 0, &aIntersect );
@@ -1343,9 +1313,9 @@ void SwTxtPaintInfo::_NotifyURL( const SwLinePortion &rPor ) const
  *************************************************************************/
 
 static void lcl_InitHyphValues( PropertyValues &rVals,
-            INT16 nMinLeading, INT16 nMinTrailing )
+            sal_Int16 nMinLeading, sal_Int16 nMinTrailing )
 {
-    INT32 nLen = rVals.getLength();
+    sal_Int32 nLen = rVals.getLength();
 
     if (0 == nLen)	// yet to be initialized?
     {
@@ -1367,7 +1337,7 @@ static void lcl_InitHyphValues( PropertyValues &rVals,
         pVal[1].Value <<= nMinTrailing;
     }
     else {
-        DBG_ERROR( "unxpected size of sequence" );
+        OSL_FAIL( "unxpected size of sequence" );
     }
 }
 
@@ -1400,8 +1370,8 @@ sal_Bool SwTxtFormatInfo::InitHyph( const sal_Bool bAutoHyphen )
         nHyphStart = nHyphWrdStart = STRING_LEN;
         nHyphWrdLen = 0;
 
-        const INT16 nMinimalLeading  = Max(rAttr.GetMinLead(), sal_uInt8(2));
-        const INT16 nMinimalTrailing = rAttr.GetMinTrail();
+        const sal_Int16 nMinimalLeading  = Max(rAttr.GetMinLead(), sal_uInt8(2));
+        const sal_Int16 nMinimalTrailing = rAttr.GetMinTrail();
         lcl_InitHyphValues( aHyphVals, nMinimalLeading, nMinimalTrailing);
     }
     return bAuto;
@@ -1524,7 +1494,7 @@ void SwTxtFormatInfo::Init()
     SetPaintOfst(0);
 }
 
-/*-----------------16.10.00 11:39-------------------
+/*--------------------------------------------------
  * There are a few differences between a copy constructor
  * and the following constructor for multi-line formatting.
  * The root is the first line inside the multi-portion,
@@ -1562,23 +1532,23 @@ SwTxtFormatInfo::SwTxtFormatInfo( const SwTxtFormatInfo& rInf,
     nMinLeading = 0;
     nMinTrailing = 0;
     nMinWordLength = 0;
-    bFull = FALSE;
-    bFtnDone = TRUE;
-    bErgoDone = TRUE;
-    bNumDone = TRUE;
-    bArrowDone = TRUE;
-    bStop = FALSE;
-    bNewLine = TRUE;
-    bShift	= FALSE;
-    bUnderFlow = FALSE;
-    bInterHyph = FALSE;
-    bAutoHyph = FALSE;
-    bDropInit = FALSE;
+    bFull = sal_False;
+    bFtnDone = sal_True;
+    bErgoDone = sal_True;
+    bNumDone = sal_True;
+    bArrowDone = sal_True;
+    bStop = sal_False;
+    bNewLine = sal_True;
+    bShift	= sal_False;
+    bUnderFlow = sal_False;
+    bInterHyph = sal_False;
+    bAutoHyph = sal_False;
+    bDropInit = sal_False;
     bQuick	= rInf.bQuick;
-    bNoEndHyph	= FALSE;
-    bNoMidHyph	= FALSE;
-    bIgnoreFly = FALSE;
-    bFakeLineStart = FALSE;
+    bNoEndHyph	= sal_False;
+    bNoMidHyph	= sal_False;
+    bIgnoreFly = sal_False;
+    bFakeLineStart = sal_False;
 
     cTabDecimal = 0;
     cHookChar = 0;
@@ -1635,12 +1605,6 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
     bool bNumFound = false;
     const bool bTabCompat = GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT);
 
-    // Removed for i7288. bSkip used to be passed from SwFldPortion::Format
-    // as IsFollow(). Therefore more than one special character was not
-    // handled correctly at the beginning of follow fields.
-//    if ( bSkip && i < nEnd )
-//       ++i;
-
     for( ; i < nEnd; ++i )
     {
         const xub_Unicode cPos = GetChar( i );
@@ -1659,8 +1623,6 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
         case CH_BREAK:
         case CHAR_ZWSP :
         case CHAR_ZWNBSP :
-//        case CHAR_RLM :
-//        case CHAR_LRM :
             cHookChar = cPos;
             return i;
 
@@ -1674,7 +1636,7 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
             {
                 if( cTabDec == cPos )
                 {
-                    ASSERT( cPos, "Unexpected end of string" );
+                    OSL_ENSURE( cPos, "Unexpected end of string" );
                     if( cPos ) // robust
                     {
                         cHookChar = cPos;
@@ -1722,15 +1684,15 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
     return i;
 }
 
-BOOL SwTxtFormatInfo::LastKernPortion()
+sal_Bool SwTxtFormatInfo::LastKernPortion()
 {
     if( GetLast() )
     {
          if( GetLast()->IsKernPortion() )
-            return TRUE;
+            return sal_True;
         if( GetLast()->Width() || ( GetLast()->GetLen() &&
             !GetLast()->IsHolePortion() ) )
-            return FALSE;
+            return sal_False;
     }
     SwLinePortion* pPor = GetRoot();
     SwLinePortion *pKern = NULL;
@@ -1745,9 +1707,9 @@ BOOL SwTxtFormatInfo::LastKernPortion()
     if( pKern )
     {
         SetLast( pKern );
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
 /*************************************************************************
@@ -1786,7 +1748,7 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
             pOldSmartTagList = static_cast<SwTxtPaintInfo*>(pInf)->GetSmartTags();
             if ( pOldSmartTagList )
             {
-                const USHORT nPos = pOldSmartTagList->GetWrongPos(nIdx);
+                const sal_uInt16 nPos = pOldSmartTagList->GetWrongPos(nIdx);
                 const xub_StrLen nListPos = pOldSmartTagList->Pos(nPos);
                 if( nListPos == nIdx )
                     ((SwTxtPaintInfo*)pInf)->SetSmartTags( pOldSmartTagList->SubList( nPos ) );
@@ -1802,7 +1764,7 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
             pOldGrammarCheckList = static_cast<SwTxtPaintInfo*>(pInf)->GetGrammarCheckList();
             if ( pOldGrammarCheckList )
             {
-                const USHORT nPos = pOldGrammarCheckList->GetWrongPos(nIdx);
+                const sal_uInt16 nPos = pOldGrammarCheckList->GetWrongPos(nIdx);
                 const xub_StrLen nListPos = pOldGrammarCheckList->Pos(nPos);
                 if( nListPos == nIdx )
                     ((SwTxtPaintInfo*)pInf)->SetGrammarCheckList( pOldGrammarCheckList->SubList( nPos ) );
@@ -1907,7 +1869,7 @@ SwFontSave::~SwFontSave()
 SwDefFontSave::SwDefFontSave( const SwTxtSizeInfo &rInf )
         : pFnt( ((SwTxtSizeInfo&)rInf).GetFont()  )
 {
-    const BOOL bTmpAlter = pFnt->GetFixKerning() ||
+    const sal_Bool bTmpAlter = pFnt->GetFixKerning() ||
          ( RTL_TEXTENCODING_SYMBOL == pFnt->GetCharSet(pFnt->GetActual()) )
         ;
 
@@ -1977,3 +1939,4 @@ sal_Bool SwTxtFormatInfo::ChgHyph( const sal_Bool bNew )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
