@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -62,28 +63,28 @@ class _HTMLAttrContext_SaveDoc
                                     // wenn Attributierung nicht
                                     // beibehalten werden soll.
 
-    USHORT nContextStMin;			// In Umgebung gueltige Stack-
+    sal_uInt16 nContextStMin;			// In Umgebung gueltige Stack-
                                     // Untergrenze, wenn der Stack
                                     // geschuetzt werden soll.
-    USHORT nContextStAttrMin;		// In Umgebung gueltige Stack-
+    sal_uInt16 nContextStAttrMin;		// In Umgebung gueltige Stack-
                                     // Untergrenze, wenn die Attribute
                                     // nicht beibehalten werden sollen.
 
-    BOOL bStripTrailingPara : 1;	// letzen Absatz entfernen?
-    BOOL bKeepNumRules : 1;			// Numerierung beibehalten?
-    BOOL bPopStack : 1;				// Stack-Elemente oberhalb des
+    sal_Bool bStripTrailingPara : 1;	// letzen Absatz entfernen?
+    sal_Bool bKeepNumRules : 1;			// Numerierung beibehalten?
+    sal_Bool bPopStack : 1;				// Stack-Elemente oberhalb des
                                     // zu schliessenden entfernen?
-    BOOL bFixHeaderDist : 1;
-    BOOL bFixFooterDist : 1;
+    sal_Bool bFixHeaderDist : 1;
+    sal_Bool bFixFooterDist : 1;
 
 public:
 
     _HTMLAttrContext_SaveDoc() :
         pPos( 0 ), pAttrTab( 0 ),
         nContextStMin( USHRT_MAX ), nContextStAttrMin( USHRT_MAX ),
-        bStripTrailingPara( FALSE ), bKeepNumRules( FALSE ),
-        bPopStack( FALSE ),
-        bFixHeaderDist( FALSE ), bFixFooterDist( FALSE )
+        bStripTrailingPara( sal_False ), bKeepNumRules( sal_False ),
+        bPopStack( sal_False ),
+        bFixHeaderDist( sal_False ), bFixFooterDist( sal_False )
     {}
 
     ~_HTMLAttrContext_SaveDoc() { delete pPos; delete pAttrTab; }
@@ -96,28 +97,28 @@ public:
     void SetNumInfo( const SwHTMLNumRuleInfo& rInf ) { aNumRuleInfo.Set(rInf); }
     const SwHTMLNumRuleInfo& GetNumInfo() const { return aNumRuleInfo; }
 
-    _HTMLAttrTable *GetAttrTab( BOOL bCreate= FALSE );
+    _HTMLAttrTable *GetAttrTab( sal_Bool bCreate= sal_False );
 
-    void SetContextStMin( USHORT nMin ) { nContextStMin = nMin; }
-    USHORT GetContextStMin() const { return nContextStMin; }
+    void SetContextStMin( sal_uInt16 nMin ) { nContextStMin = nMin; }
+    sal_uInt16 GetContextStMin() const { return nContextStMin; }
 
-    void SetContextStAttrMin( USHORT nMin ) { nContextStAttrMin = nMin; }
-    USHORT GetContextStAttrMin() const { return nContextStAttrMin; }
+    void SetContextStAttrMin( sal_uInt16 nMin ) { nContextStAttrMin = nMin; }
+    sal_uInt16 GetContextStAttrMin() const { return nContextStAttrMin; }
 
-    void SetStripTrailingPara( BOOL bSet ) { bStripTrailingPara = bSet; }
-    BOOL GetStripTrailingPara() const { return bStripTrailingPara; }
+    void SetStripTrailingPara( sal_Bool bSet ) { bStripTrailingPara = bSet; }
+    sal_Bool GetStripTrailingPara() const { return bStripTrailingPara; }
 
-    void SetKeepNumRules( BOOL bSet ) { bKeepNumRules = bSet; }
-    BOOL GetKeepNumRules() const { return bKeepNumRules; }
+    void SetKeepNumRules( sal_Bool bSet ) { bKeepNumRules = bSet; }
+    sal_Bool GetKeepNumRules() const { return bKeepNumRules; }
 
-    void SetFixHeaderDist( BOOL bSet ) { bFixHeaderDist = bSet; }
-    BOOL GetFixHeaderDist() const { return bFixHeaderDist; }
+    void SetFixHeaderDist( sal_Bool bSet ) { bFixHeaderDist = bSet; }
+    sal_Bool GetFixHeaderDist() const { return bFixHeaderDist; }
 
-    void SetFixFooterDist( BOOL bSet ) { bFixFooterDist = bSet; }
-    BOOL GetFixFooterDist() const { return bFixFooterDist; }
+    void SetFixFooterDist( sal_Bool bSet ) { bFixFooterDist = bSet; }
+    sal_Bool GetFixFooterDist() const { return bFixFooterDist; }
 };
 
-_HTMLAttrTable *_HTMLAttrContext_SaveDoc::GetAttrTab( BOOL bCreate )
+_HTMLAttrTable *_HTMLAttrContext_SaveDoc::GetAttrTab( sal_Bool bCreate )
 {
     if( !pAttrTab && bCreate )
     {
@@ -129,7 +130,7 @@ _HTMLAttrTable *_HTMLAttrContext_SaveDoc::GetAttrTab( BOOL bCreate )
 
 /*  */
 
-_HTMLAttrContext_SaveDoc *_HTMLAttrContext::GetSaveDocContext( BOOL bCreate )
+_HTMLAttrContext_SaveDoc *_HTMLAttrContext::GetSaveDocContext( sal_Bool bCreate )
 {
     if( !pSaveDocContext && bCreate )
         pSaveDocContext = new _HTMLAttrContext_SaveDoc;
@@ -149,7 +150,7 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
 {
     // Hier darf es keine vorlauefigen Absatz-Attribute geben, den die
     // koennten jetzt gesetzt werden und dann sind die Zeiger ungueltig!!!
-    ASSERT( !aParaAttrs.Count(),
+    OSL_ENSURE( !aParaAttrs.Count(),
         "Hoechste Gefahr: Es gibt noch nicht-endgueltige Absatz-Attribute" );
     if( aParaAttrs.Count() )
         aParaAttrs.Remove( 0, aParaAttrs.Count() );
@@ -160,12 +161,12 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
     const SwNodeIndex& rNewSttPara = rNewPos.nNode;
     xub_StrLen nNewSttCnt = rNewPos.nContent.GetIndex();
 
-    BOOL bMoveBack = FALSE;
+    sal_Bool bMoveBack = sal_False;
 
     // alle noch offenen Attribute beenden und hinter der Tabelle
     // neu aufspannen
     _HTMLAttr** pTbl = (_HTMLAttr**)&aAttrTab;
-    for( USHORT nCnt = sizeof( _HTMLAttrTable ) / sizeof( _HTMLAttr* );
+    for( sal_uInt16 nCnt = sizeof( _HTMLAttrTable ) / sizeof( _HTMLAttr* );
             nCnt--; ++pTbl )
     {
         _HTMLAttr *pAttr = *pTbl;
@@ -174,7 +175,7 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
             _HTMLAttr *pNext = pAttr->GetNext();
             _HTMLAttr *pPrev = pAttr->GetPrev();
 
-            USHORT nWhich = pAttr->pItem->Which();
+            sal_uInt16 nWhich = pAttr->pItem->Which();
             if( !nOldEndCnt && RES_PARATR_BEGIN <= nWhich &&
                 pAttr->GetSttParaIdx() < pOldEndPara->GetIndex() )
             {
@@ -192,7 +193,7 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
                 nOldEndCnt = pPam->GetPoint()->nContent.GetIndex();
             }
 
-            if( RES_PARATR_BEGIN <= nWhich && bMoveBack ||
+            if( (RES_PARATR_BEGIN <= nWhich && bMoveBack) ||
                 pAttr->GetSttParaIdx() < pOldEndPara->GetIndex() ||
                 (pAttr->GetSttPara() == *pOldEndPara &&
                  pAttr->GetSttCnt() != nOldEndCnt) )
@@ -208,7 +209,7 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
                     pNext->InsertPrev( pSetAttr );
                 else
                 {
-                    USHORT nTmp =
+                    sal_uInt16 nTmp =
                         pSetAttr->bInsAtStart ? 0 : aSetAttrTab.Count();
                     aSetAttrTab.Insert( pSetAttr, nTmp );
                 }
@@ -222,7 +223,7 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
                     pNext->InsertPrev( pPrev );
                 else
                 {
-                    USHORT nTmp = pPrev->bInsAtStart ? 0 : aSetAttrTab.Count();
+                    sal_uInt16 nTmp = pPrev->bInsAtStart ? 0 : aSetAttrTab.Count();
                     aSetAttrTab.Insert( pPrev, nTmp );
                 }
             }
@@ -244,10 +245,10 @@ void SwHTMLParser::SplitAttrTab( const SwPosition& rNewPos )
 }
 
 void SwHTMLParser::SaveDocContext( _HTMLAttrContext *pCntxt,
-                                   USHORT nFlags,
+                                   sal_uInt16 nFlags,
                                    const SwPosition *pNewPos )
 {
-    _HTMLAttrContext_SaveDoc *pSave = pCntxt->GetSaveDocContext( TRUE );
+    _HTMLAttrContext_SaveDoc *pSave = pCntxt->GetSaveDocContext( sal_True );
     pSave->SetStripTrailingPara( (HTML_CNTXT_STRIP_PARA & nFlags) != 0 );
     pSave->SetKeepNumRules( (HTML_CNTXT_KEEP_NUMRULE & nFlags) != 0 );
     pSave->SetFixHeaderDist( (HTML_CNTXT_HEADER_DIST & nFlags) != 0 );
@@ -273,7 +274,7 @@ void SwHTMLParser::SaveDocContext( _HTMLAttrContext *pCntxt,
         }
         else
         {
-            _HTMLAttrTable *pSaveAttrTab = pSave->GetAttrTab( TRUE );
+            _HTMLAttrTable *pSaveAttrTab = pSave->GetAttrTab( sal_True );
             SaveAttrTab( *pSaveAttrTab );
         }
 
@@ -357,7 +358,7 @@ void SwHTMLParser::EndContext( _HTMLAttrContext *pContext )
         while( aContexts.Count() > nContextStMin )
         {
             _HTMLAttrContext *pCntxt = PopContext();
-            ASSERT( pCntxt != pContext,
+            OSL_ENSURE( pCntxt != pContext,
                     "Kontext noch im Stack" );
             if( pCntxt == pContext )
                 break;
@@ -403,7 +404,7 @@ void SwHTMLParser::EndContext( _HTMLAttrContext *pContext )
 void SwHTMLParser::ClearContext( _HTMLAttrContext *pContext )
 {
     _HTMLAttrs &rAttrs = pContext->GetAttrs();
-    for( USHORT i=0; i<rAttrs.Count(); i++ )
+    for( sal_uInt16 i=0; i<rAttrs.Count(); i++ )
     {
         // einfaches Loeschen reicht hier nicht, weil das
         // Attribut auch aus seiner Liste ausgetragen werden
@@ -413,10 +414,10 @@ void SwHTMLParser::ClearContext( _HTMLAttrContext *pContext )
         DeleteAttr( rAttrs[i] );
     }
 
-    ASSERT( !pContext->GetSpansSection(),
+    OSL_ENSURE( !pContext->GetSpansSection(),
             "Bereich kann nicht mehr verlassen werden" );
 
-    ASSERT( !pContext->HasSaveDocContext(),
+    OSL_ENSURE( !pContext->HasSaveDocContext(),
             "Rahmen kann nicht mehr verlassen werden" );
 
     // PRE-/LISTING- und XMP-Umgebungen wieder starten
@@ -435,11 +436,11 @@ void SwHTMLParser::ClearContext( _HTMLAttrContext *pContext )
 
 /*  */
 
-BOOL SwHTMLParser::DoPositioning( SfxItemSet &rItemSet,
+sal_Bool SwHTMLParser::DoPositioning( SfxItemSet &rItemSet,
                                   SvxCSS1PropertyInfo &rPropInfo,
                                   _HTMLAttrContext *pContext )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     // Unter folgenden Umstaenden wird jetzt ein Rahmen aufgemacht:
     // - das Tag wird absolut positioniert und left/top sind beide
@@ -470,20 +471,20 @@ BOOL SwHTMLParser::DoPositioning( SfxItemSet &rItemSet,
 
         InsertFlyFrame( aFrmItemSet, pContext, rPropInfo.aId,
                         CONTEXT_FLAGS_ABSPOS );
-        pContext->SetPopStack( TRUE );
+        pContext->SetPopStack( sal_True );
         rPropInfo.aId.Erase();
-        bRet = TRUE;
+        bRet = sal_True;
     }
 
     return bRet;
 }
 
-BOOL SwHTMLParser::CreateContainer( const String& rClass,
+sal_Bool SwHTMLParser::CreateContainer( const String& rClass,
                                     SfxItemSet &rItemSet,
                                     SvxCSS1PropertyInfo &rPropInfo,
                                     _HTMLAttrContext *pContext )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     if( rClass.EqualsIgnoreCaseAscii(sCSS1_class_abs_pos) &&
         pCSS1Parser->MayBePositioned( rPropInfo ) )
     {
@@ -495,13 +496,13 @@ BOOL SwHTMLParser::CreateContainer( const String& rClass,
         SetAnchorAndAdjustment( text::VertOrientation::NONE, text::HoriOrientation::NONE,
                                 rItemSet, rPropInfo, *pFrmItemSet );
         Size aDummy(0,0);
-        SetFixSize( aDummy, aDummy, FALSE, FALSE, rItemSet, rPropInfo,
+        SetFixSize( aDummy, aDummy, sal_False, sal_False, rItemSet, rPropInfo,
                     *pFrmItemSet );
         SetSpace( aDummy, rItemSet, rPropInfo, *pFrmItemSet );
         SetFrmFmtAttrs( rItemSet, rPropInfo, HTML_FF_BOX|HTML_FF_BACKGROUND|HTML_FF_DIRECTION,
                         *pFrmItemSet );
 
-        bRet = TRUE;
+        bRet = sal_True;
     }
 
     return bRet;
@@ -512,7 +513,7 @@ BOOL SwHTMLParser::CreateContainer( const String& rClass,
 void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
                                 SvxCSS1PropertyInfo &rPropInfo,
                                 _HTMLAttrContext *pContext,
-                                BOOL bCharLvl )
+                                sal_Bool bCharLvl )
 {
     // Ein DropCap-Attribut basteln, wenn auf Zeichen-Ebene vor dem
     // ersten Zeichen ein float: left vorkommt
@@ -542,7 +543,7 @@ void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
         pCSS1Parser->SetFmtBreak( rItemSet, rPropInfo );
 // /Feature: PrintExt
 
-    ASSERT( aContexts.Count() <= nContextStAttrMin ||
+    OSL_ENSURE( aContexts.Count() <= nContextStAttrMin ||
             aContexts[aContexts.Count()-1] != pContext,
             "SwHTMLParser::InsertAttrs: Kontext doch schon auf dem Stack" );
 
@@ -566,16 +567,16 @@ void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
 
                 // die bisherigen Absatz-Abstaende holen (ohne die vom
                 // obersten Kontext, denn den veraendern wir ja gerade) ...
-                USHORT nOldLeft = 0, nOldRight = 0;
+                sal_uInt16 nOldLeft = 0, nOldRight = 0;
                 short nOldIndent = 0;
-                BOOL bIgnoreTop = aContexts.Count() > nContextStMin &&
+                sal_Bool bIgnoreTop = aContexts.Count() > nContextStMin &&
                                   aContexts[aContexts.Count()-1] == pContext;
                 GetMarginsFromContext( nOldLeft, nOldRight, nOldIndent,
                                        bIgnoreTop  );
 
 
                 // und noch die aktuell gueltigen
-                USHORT nLeft = nOldLeft, nRight = nOldRight;
+                sal_uInt16 nLeft = nOldLeft, nRight = nOldRight;
                 short nIndent = nOldIndent;
                 pContext->GetMargins( nLeft, nRight, nIndent );
 
@@ -587,25 +588,25 @@ void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
                 // eingefuegt.
                 if( rPropInfo.bLeftMargin )
                 {
-                    ASSERT( rPropInfo.nLeftMargin < 0 ||
+                    OSL_ENSURE( rPropInfo.nLeftMargin < 0 ||
                             rPropInfo.nLeftMargin == pLRItem->GetTxtLeft(),
                             "linker Abstand stimmt nicht mit Item ueberein" );
                     if( rPropInfo.nLeftMargin < 0 &&
                         -rPropInfo.nLeftMargin > nOldLeft )
                         nLeft = 0;
                     else
-                        nLeft = nOldLeft + static_cast< USHORT >(rPropInfo.nLeftMargin);
+                        nLeft = nOldLeft + static_cast< sal_uInt16 >(rPropInfo.nLeftMargin);
                 }
                 if( rPropInfo.bRightMargin )
                 {
-                    ASSERT( rPropInfo.nRightMargin < 0 ||
+                    OSL_ENSURE( rPropInfo.nRightMargin < 0 ||
                             rPropInfo.nRightMargin == pLRItem->GetRight(),
                             "rechter Abstand stimmt nicht mit Item ueberein" );
                     if( rPropInfo.nRightMargin < 0 &&
                         -rPropInfo.nRightMargin > nOldRight )
                         nRight = 0;
                     else
-                        nRight = nOldRight + static_cast< USHORT >(rPropInfo.nRightMargin);
+                        nRight = nOldRight + static_cast< sal_uInt16 >(rPropInfo.nRightMargin);
                 }
                 if( rPropInfo.bTextIndent )
                     nIndent = pLRItem->GetTxtFirstLineOfst();
@@ -619,14 +620,14 @@ void SwHTMLParser::InsertAttrs( SfxItemSet &rItemSet,
                 aLRItem.SetTxtLeft( nLeft );
                 aLRItem.SetRight( nRight );
                 NewAttr( &aAttrTab.pLRSpace, aLRItem );
-                EndAttr( aAttrTab.pLRSpace, 0, FALSE );
+                EndAttr( aAttrTab.pLRSpace, 0, sal_False );
             }
             break;
 
         case RES_UL_SPACE:
             if( !rPropInfo.bTopMargin || !rPropInfo.bBottomMargin )
             {
-                USHORT nUpper = 0, nLower = 0;
+                sal_uInt16 nUpper = 0, nLower = 0;
                 GetULSpaceFromContext( nUpper, nLower );
                 SvxULSpaceItem aULSpace( *((const SvxULSpaceItem *)pItem) );
                 if( !rPropInfo.bTopMargin )
@@ -729,15 +730,15 @@ void SwHTMLParser::InsertAttr( _HTMLAttr **ppAttr, const SfxPoolItem & rItem,
 void SwHTMLParser::SplitPREListingXMP( _HTMLAttrContext *pCntxt )
 {
     // PRE/Listing/XMP soll beim beenden des Kontexts beendet werden.
-    pCntxt->SetFinishPREListingXMP( TRUE );
+    pCntxt->SetFinishPREListingXMP( sal_True );
 
     // Und die jetzt gueltigen Flags sollen wieder gesetzt werden.
     if( IsReadPRE() )
-        pCntxt->SetRestartPRE( TRUE );
+        pCntxt->SetRestartPRE( sal_True );
     if( IsReadXMP() )
-        pCntxt->SetRestartXMP( TRUE );
+        pCntxt->SetRestartXMP( sal_True );
     if( IsReadListing() )
-        pCntxt->SetRestartListing( TRUE );
+        pCntxt->SetRestartListing( sal_True );
 
     // PRE/Listing/XMP wird auuserdem sofort beendet
     FinishPREListingXMP();
@@ -750,3 +751,5 @@ SfxItemSet *_HTMLAttrContext::GetFrmItemSet( SwDoc *pCreateDoc )
                         RES_FRMATR_BEGIN, RES_FRMATR_END-1 );
     return pFrmItemSet;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
