@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -51,6 +52,7 @@
 #include <doc.hxx>
 #include <swmodule.hxx>
 #include <docsh.hxx>
+#include <viewsh.hxx>
 #include <docstat.hxx>
 #include <swerror.h>
 #include <unotext.hxx>
@@ -65,11 +67,9 @@
 
 // for locking SolarMutex: svapp + mutex
 #include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
-// --> OD 2007-03-30 #i73788#
-#include <pausethreadstarting.hxx>
-// <--
+#include <pausethreadstarting.hxx> // #i73788#
 
 
 using ::rtl::OUString;
@@ -124,7 +124,6 @@ void SwXMLExport::SetCurPaM( SwPaM& rPaM, sal_Bool bWhole, sal_Bool bTabOnly )
 }
 #endif
 
-// #110680#
 SwXMLExport::SwXMLExport(
     const uno::Reference< lang::XMultiServiceFactory > xServiceFactory,
     sal_uInt16 nExportFlags)
@@ -149,7 +148,7 @@ SwXMLExport::SwXMLExport(
 }
 
 #ifdef XML_CORE_API
-// #110680#
+
 SwXMLExport::SwXMLExport(
     const uno::Reference< lang::XMultiServiceFactory > xServiceFactory,
     const Reference< XModel >& rModel,
@@ -187,19 +186,17 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     if( !GetModel().is() )
         return ERR_SWG_WRITE_ERROR;
 
-    // --> OD 2007-03-30 #i73788#
-    SwPauseThreadStarting aPauseThreadStarting;
-    // <--
+    SwPauseThreadStarting aPauseThreadStarting; // #i73788#
 
     Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
     Reference < XText > xText = xTextDoc->getText();
     Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-    ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+    OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
     if( !xTextTunnel.is() )
         return ERR_SWG_WRITE_ERROR;
 
-    // from here, we use core interfaces -> lock Solar-Mutex (#91949#)
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    // from here, we use core interfaces -> lock Solar-Mutex
+    SolarMutexGuard aGuard;
 
     {
         Reference<XPropertySet> rInfoSet = getExportInfo();
@@ -220,7 +217,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
 
     SwXText *pText = reinterpret_cast< SwXText * >(
             sal::static_int_cast< sal_IntPtr >( xTextTunnel->getSomething( SwXText::getUnoTunnelId() )));
-    ASSERT( pText, "SwXText missing" );
+    OSL_ENSURE( pText, "SwXText missing" );
     if( !pText )
         return ERR_SWG_WRITE_ERROR;
 
@@ -244,14 +241,14 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
         for( sal_uInt16 j=0; j < nWhichIds; j++ )
         {
             sal_uInt16 nWhichId = aWhichIds[j];
-            sal_uInt16 i=0, nItems = rPool.GetItemCount( nWhichId );
+            sal_uInt32 i=0, nItems = rPool.GetItemCount2( nWhichId );
             for( i = 0; i < nItems; ++i )
             {
-                if( 0 != (pItem = rPool.GetItem( nWhichId , i ) ) )
+                if( 0 != (pItem = rPool.GetItem2( nWhichId , i ) ) )
                 {
                     const SvXMLAttrContainerItem *pUnknown =
                                 PTR_CAST( SvXMLAttrContainerItem, pItem );
-                    ASSERT( pUnknown, "illegal attribute container item" );
+                    OSL_ENSURE( pUnknown, "illegal attribute container item" );
                     if( pUnknown && (pUnknown->GetAttrCount() > 0) )
                     {
                         sal_uInt16 nIdx = pUnknown->GetFirstNamespaceIndex();
@@ -320,7 +317,6 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
             nRef += pDoc->GetCharFmts()->Count() - 1;
             nRef += pDoc->GetFrmFmts()->Count() - 1;
             nRef += pDoc->GetTxtFmtColls()->Count() - 1;
-//			nRef += pDoc->GetPageDescCnt();
             nRef *= 2; // for the above styles, xmloff will increment by 2!
             // #i93174#: count all paragraphs for the progress bar
             nRef += aDocStat.nAllPara; // 1: only content, no autostyle
@@ -412,7 +408,7 @@ sal_uInt32 SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     if( pEmbeddedResolver )
         SvXMLEmbeddedObjectHelper::Destroy( pEmbeddedResolver );
 
-    ASSERT( !pTableLines, "there are table columns infos left" );
+    OSL_ENSURE( !pTableLines, "there are table columns infos left" );
 
     return nRet;
 }
@@ -435,8 +431,9 @@ XMLShapeExport* SwXMLExport::CreateShapeExport()
     return pShapeExport;
 }
 
-__EXPORT SwXMLExport::~SwXMLExport()
+SwXMLExport::~SwXMLExport()
 {
+    DeleteTableLines();
     _FinitItemExport();
 }
 
@@ -452,7 +449,7 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
 {
     Reference< XMultiServiceFactory > xServiceFactory =
             comphelper::getProcessServiceFactory();
-    ASSERT( xServiceFactory.is(),
+    OSL_ENSURE( xServiceFactory.is(),
             "XMLReader::Read: got no service manager" );
     if( !xServiceFactory.is() )
         return;
@@ -478,12 +475,12 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
         Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
         xText = xTextDoc->getText();
         Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-        ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+        OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
         if( xTextTunnel.is() )
         {
             pText = reinterpret_cast< SwXText * >(
                     sal::static_int_cast< sal_IntPtr >( xTextTunnel->getSomething( SwXText::getUnoTunnelId()) ));
-            ASSERT( pText, "SwXText missing" );
+            OSL_ENSURE( pText, "SwXText missing" );
         }
     }
 
@@ -498,7 +495,7 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
         pDoc->GetDocShell()->GetVisArea( ASPECT_CONTENT );
     sal_Bool bTwip = pDoc->GetDocShell()->GetMapUnit ( ) == MAP_TWIP;
 
-    ASSERT ( bTwip, "Map unit for visible area is not in TWIPS!" );
+   OSL_ENSURE( bTwip, "Map unit for visible area is not in TWIPS!" );
 
     pValue[nIndex].Name = OUString( RTL_CONSTASCII_USTRINGPARAM ( "ViewAreaTop") );
     pValue[nIndex++].Value <<= bTwip ? TWIP_TO_MM100 ( rRect.Top() ) : rRect.Top();
@@ -574,16 +571,17 @@ void SwXMLExport::SetBodyAttributes()
     // export use of soft page breaks
     {
         Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-        ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+        OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
         if( xTextTunnel.is() )
         {
             SwXText *pText = reinterpret_cast< SwXText * >(
                     sal::static_int_cast< sal_IntPtr >( xTextTunnel->getSomething( SwXText::getUnoTunnelId() )));
-            ASSERT( pText, "SwXText missing" );
+            OSL_ENSURE( pText, "SwXText missing" );
             if( pText )
             {
                 SwDoc *pDoc = pText->GetDoc();
-                if( pDoc && pDoc->GetPageCount() > 1 )
+                if( pDoc && pDoc->GetCurrentViewShell() &&
+                    pDoc->GetCurrentViewShell()->GetPageCount() > 1 )
                 {
                     sal_Bool bValue = sal_True;
                     rtl::OUStringBuffer sBuffer;
@@ -607,13 +605,12 @@ void SwXMLExport::_ExportContent()
         Reference<XDrawPage> xPage = xDrawPageSupplier->getDrawPage();
         if (xPage.is())
         {
-            // #103597# prevent export of form controls which are embedded in
-            // mute sections
+            // prevent export of form controls which are embedded in mute sections
             Reference<XIndexAccess> xIAPage( xPage, UNO_QUERY );
             GetTextParagraphExport()->PreventExportOfControlsInMuteSections(
                 xIAPage, GetFormExport() );
 
-            // #i36597# / 2004-12-13 / fs@openoffice.org
+            // #i36597#
             if ( GetFormExport()->pageContainsForms( xPage ) || GetFormExport()->documentContainsXForms() )
             {
                 ::xmloff::OOfficeFormsExport aOfficeForms(*this);
@@ -811,10 +808,6 @@ Reference< XInterface > SAL_CALL SwXMLExportStyles_createInstance(
         const Reference< XMultiServiceFactory > & rSMgr)
     throw( Exception )
 {
-    // #110680#
-    //return (cppu::OWeakObject*)new SwXMLExport(
-    //	EXPORT_STYLES | EXPORT_MASTERSTYLES | EXPORT_AUTOSTYLES |
-    //	EXPORT_FONTDECLS );
     return (cppu::OWeakObject*)new SwXMLExport( rSMgr,
         EXPORT_STYLES | EXPORT_MASTERSTYLES | EXPORT_AUTOSTYLES |
         EXPORT_FONTDECLS|EXPORT_OASIS );
@@ -838,10 +831,6 @@ Reference< XInterface > SAL_CALL SwXMLExportContent_createInstance(
         const Reference< XMultiServiceFactory > & rSMgr)
     throw( Exception )
 {
-    // #110680#
-    //return (cppu::OWeakObject*)new SwXMLExport(
-    //	EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS |
-    //	EXPORT_FONTDECLS );
     return (cppu::OWeakObject*)new SwXMLExport(
         rSMgr,
         EXPORT_AUTOSTYLES | EXPORT_CONTENT | EXPORT_SCRIPTS |
@@ -955,7 +944,7 @@ void SwXMLExport::ExportCurPaM( sal_Bool bExportWholePaM )
         aNextNumInfo.Set( *pNd );
         ExportListChange( aPrevNumInfo, aNextNumInfo );
 
-        ASSERT( !(pNd->IsGrfNode() || pNd->IsOLENode()),
+        OSL_ENSURE( !(pNd->IsGrfNode() || pNd->IsOLENode()),
                 "SwXMLExport::exportCurPaM: grf or OLE node unexpected" );
         if( pNd->IsTxtNode() )
         {
@@ -993,3 +982,5 @@ void SwXMLExport::ExportCurPaM( sal_Bool bExportWholePaM )
     ExportListChange( aPrevNumInfo, aNextNumInfo );
 }
 #endif
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
