@@ -32,7 +32,6 @@
 
 #include <tools/stream.hxx>
 #include <unotools/syslocale.hxx>
-#include <svl/cjkoptions.hxx>
 
 #include "swtypes.hxx"
 #include "hintids.hxx"
@@ -74,17 +73,8 @@ SwMasterUsrPref::SwMasterUsrPref(sal_Bool bWeb) :
     bApplyCharUnit(sal_False)
 {
     MeasurementSystem eSystem = SvtSysLocale().GetLocaleData().getMeasurementSystemEnum();
-    SvtCJKOptions aCJKOptions;
     eUserMetric = MEASURE_METRIC == eSystem ? FUNIT_CM : FUNIT_INCH;
 
-    sal_Bool bCJKEnabled = aCJKOptions.IsAsianTypographyEnabled();
-    bApplyCharUnit = bCJKEnabled;
-    eHScrollMetric = bApplyCharUnit ? FUNIT_CHAR : eUserMetric;
-    eVScrollMetric = bApplyCharUnit ? FUNIT_LINE : eUserMetric;
-
-    bIsHScrollMetricSet = bApplyCharUnit;
-    bIsVScrollMetricSet = bApplyCharUnit;
-
     aContentConfig.Load();
     aLayoutConfig.Load();
     aGridConfig.Load();
