@@ -539,7 +539,7 @@ void SwView::InsertThesaurusSynonym( const String &rSynonmText, const String &rL
     if( !bSelection )
     {
         if(pWrtShell->IsEndWrd())
-            pWrtShell->Left(CRSR_SKIP_CELLS, FALSE, 1, FALSE );
+            pWrtShell->Left(CRSR_SKIP_CELLS, sal_False, 1, sal_False );
 
         pWrtShell->SelWrd();
 
@@ -559,8 +559,8 @@ void SwView::InsertThesaurusSynonym( const String &rSynonmText, const String &rL
 
         // adjust existing selection
         SwPaM *pCrsr = pWrtShell->GetCrsr();
-        pCrsr->GetPoint()->nContent/*.nIndex*/ -= nRight;
-        pCrsr->GetMark()->nContent/*.nIndex*/ += nLeft;
+        pCrsr->GetPoint()->nContent -= nRight;
+        pCrsr->GetMark()->nContent += nLeft;
     }
 
     pWrtShell->Insert( rSynonmText );
@@ -685,13 +685,13 @@ sal_Bool SwView::ExecSpellPopup(const Point& rPt)
             // default context menu.
             bool bUseGrammarContext = false;
             Reference< XSpellAlternatives >  xAlt( pWrtShell->GetCorrection(&rPt, aToFill) );
-            /*linguistic2::*/ProofreadingResult aGrammarCheckRes;
-            sal_Int32 nErrorPosInText = -1;
+            ProofreadingResult aGrammarCheckRes;
             sal_Int32 nErrorInResult = -1;
             uno::Sequence< rtl::OUString > aSuggestions;
             bool bCorrectionRes = false;
             if (!xAlt.is() || xAlt->getAlternatives().getLength() == 0)
             {
+                sal_Int32 nErrorPosInText = -1;
                 bCorrectionRes = pWrtShell->GetGrammarCorrection( aGrammarCheckRes, nErrorPosInText, nErrorInResult, aSuggestions, &rPt, aToFill );
                 ::rtl::OUString aMessageText;
                 if (nErrorInResult >= 0)
@@ -715,7 +715,7 @@ sal_Bool SwView::ExecSpellPopup(const Point& rPt)
                     aParaText = pNode->GetTxt();	// this may include hidden text but that should be Ok
                 else 
                 {
-                    OSL_ENSURE(false, "text node expected but not found" );
+                    OSL_FAIL("text node expected but not found" );
                 }
 
                 bRet = sal_True;
@@ -737,8 +737,8 @@ sal_Bool SwView::ExecSpellPopup(const Point& rPt)
                 aEvent.ExecutePosition.Y = aPixPos.Y();
                 Menu* pMenu = 0;
 
-                ::rtl::OUString sMenuName = ::rtl::OUString::createFromAscii( 
-                    bUseGrammarContext ? "private:resource/GrammarContextMenu" : "private:resource/SpellContextMenu");
+                ::rtl::OUString sMenuName  = bUseGrammarContext ?
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("private:resource/GrammarContextMenu")) : OUString(RTL_CONSTASCII_USTRINGPARAM("private:resource/SpellContextMenu"));
                 if(TryContextMenuInterception( *pPopup, sMenuName, pMenu, aEvent ))
                 {
                     
@@ -747,7 +747,7 @@ sal_Bool SwView::ExecSpellPopup(const Point& rPt)
                     if ( pMenu )
                     {
                         OUString aSlotURL( RTL_CONSTASCII_USTRINGPARAM( "slot:" ));
-                        USHORT nId = ((PopupMenu*)pMenu)->Execute(pEditWin, aPixPos);
+                        sal_uInt16 nId = ((PopupMenu*)pMenu)->Execute(pEditWin, aPixPos);
                         OUString aCommand = ((PopupMenu*)pMenu)->GetItemCommand(nId);
                         if (aCommand.getLength() == 0 )
                         {
@@ -844,56 +844,32 @@ sal_Bool SwView::ExecSmartTagPopup( const Point& rPt )
     return bRet;
 }
 
-class SwFieldPopup : public PopupMenu
-{
-public:
-    SwFieldPopup()  {
-    InsertItem(1, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Hello")));
-    }
-};
-
-class SwFieldListBox : public ListBox
-{
-public:
-    SwFieldListBox(Window* pParent) : ListBox(pParent /*, WB_DROPDOWN*/) {
-    }
-
-    void *GetImplWin() {
-    return NULL; //FIXME!!!
-//	return mpImplWin;
-    }
-
-protected:
-    virtual void LoseFocus() {
-//	printf("ListBox: lose focus!!\n");
-    ListBox::LoseFocus();
-    }    
-
-    virtual void Select() {
-//	printf("SELECT!!! IsTravelSelect=%i\n", IsTravelSelect());
-    ListBox::Select();
-    }
-};
-
-class SwFieldDialog : public Dialog
+class SwFieldDialog : public FloatingWindow
 {
 private:
-    SwFieldListBox aListBox;
-    Edit aText;
-    int selection;
+    ListBox aListBox;
+    IFieldmark *pFieldmark;
 
     DECL_LINK( MyListBoxHandler, ListBox * );
 
 public:
-    SwFieldDialog(Window* parent, IFieldmark *fieldBM) : Dialog(parent, WB_BORDER | WB_SYSTEMWINDOW | WB_NOSHADOW ), aListBox(this), aText(this, WB_RIGHT | WB_READONLY), selection(-1) {
+    SwFieldDialog( SwEditWin* parent, IFieldmark *fieldBM );
+};
 
-    assert(fieldBM!=NULL);
-    if (fieldBM!=NULL) {
+SwFieldDialog::SwFieldDialog( SwEditWin* parent, IFieldmark *fieldBM ) :
+    FloatingWindow( parent, WB_BORDER | WB_SYSTEMWINDOW ),
+    aListBox(this),
+    pFieldmark( fieldBM )
+{
+    if ( fieldBM != NULL )
+    {
         const IFieldmark::parameter_map_t* const pParameters = fieldBM->GetParameters();
-        IFieldmark::parameter_map_t::const_iterator pListEntries = pParameters->find(::rtl::OUString::createFromAscii(ODF_FORMDROPDOWN_LISTENTRY));
+
+        rtl::OUString sListKey = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ODF_FORMDROPDOWN_LISTENTRY ) );
+        IFieldmark::parameter_map_t::const_iterator pListEntries = pParameters->find( sListKey );
         if(pListEntries != pParameters->end())
         {
-            Sequence< ::rtl::OUString> vListEntries;
+            Sequence< ::rtl::OUString > vListEntries;
             pListEntries->second >>= vListEntries;
             for( ::rtl::OUString* pCurrent = vListEntries.getArray();
                 pCurrent != vListEntries.getArray() + vListEntries.getLength();
@@ -902,82 +878,68 @@ public:
                 aListBox.InsertEntry(*pCurrent);
             }
         }
+
+        // Select the current one
+        rtl::OUString sResultKey = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ODF_FORMDROPDOWN_RESULT ) );
+        IFieldmark::parameter_map_t::const_iterator pResult = pParameters->find( sResultKey );
+        if ( pResult != pParameters->end() )
+        {
+            sal_Int32 nSelection = -1;
+            pResult->second >>= nSelection;
+            aListBox.SelectEntryPos( nSelection );
+        }
     }
+
     Size lbSize=aListBox.GetOptimalSize(WINDOWSIZE_PREFERRED);
     lbSize.Width()+=50;
     lbSize.Height()+=20;
     aListBox.SetSizePixel(lbSize);
     aListBox.SetSelectHdl( LINK( this, SwFieldDialog, MyListBoxHandler ) );
     aListBox.Show();
-    aText.SetText(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Cancel")));
-    Size tSize=aText.GetOptimalSize(WINDOWSIZE_PREFERRED);
-    aText.SetSizePixel(Size(lbSize.Width(), tSize.Height()));
-    aText.SetPosPixel(Point(0, lbSize.Height()));     	
-    aText.Show();
-    SetSizePixel(Size(lbSize.Width(), lbSize.Height()+tSize.Height()));	
-//	SetSizePixel(Size(200, 200));
-    }
 
-    int getSelection() {
-    return selection;
-    }
-protected:
-    /*
-    virtual void LoseFocus() {
-    printf("lose focus!!\n");
-    Dialog::LoseFocus();
-    printf("close:\n");
-    EndDialog(8);
-    }
-    */
-
-    virtual long PreNotify( NotifyEvent& rNEvt ) {
-    if (rNEvt.GetType() == EVENT_LOSEFOCUS && aListBox.GetImplWin()==rNEvt.GetWindow()) {
-        EndDialog(8);
-        return 1;	   
-    }
-    if (rNEvt.GetType() == EVENT_KEYINPUT) {
-//	    printf("PreNotify::KEYINPUT\n");
-    }
-    return Dialog::PreNotify(rNEvt);
-    }
-};
+    SetSizePixel( lbSize );
+}
 
 IMPL_LINK( SwFieldDialog, MyListBoxHandler, ListBox *, pBox )
 {
-//    printf("### DROP DOWN SELECT... IsTravelSelect=%i\n", pBox->IsTravelSelect());
-    if (pBox->IsTravelSelect()) {
-    return 0;
-    } else {
-    this->selection=pBox->GetSelectEntryPos();
-    EndDialog(9); //@TODO have meaningfull returns...
-    return 1;
+    short res = 0;
+    if ( !pBox->IsTravelSelect() )
+    {
+        sal_Int32 selection = pBox->GetSelectEntryPos();
+        if ( selection >= 0 )
+        {
+            rtl::OUString sKey = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ODF_FORMDROPDOWN_RESULT ) );
+            (*pFieldmark->GetParameters())[ sKey ] = makeAny(selection);
+            pFieldmark->Invalidate();
+            SwView& rView = ( ( SwEditWin* )GetParent() )->GetView();
+            rView.GetDocShell()->SetModified( sal_True );
+        }
+
+        EndPopupMode();
+        res = 1;
     }
+    return res;
 }
 
-BOOL SwView::ExecFieldPopup( const Point& rPt, IFieldmark *fieldBM )
+IMPL_LINK( SwView, FieldPopupModeEndHdl, FloatingWindow*, EMPTYARG )
 {
-    sal_Bool bRet = sal_False;
-    const sal_Bool bOldViewLock = pWrtShell->IsViewLocked();
-    pWrtShell->LockView( sal_True );
-    pWrtShell->Push();
+    if ( mpFieldPopup )
+    {
+        delete mpFieldPopup;
+        mpFieldPopup = NULL;
+    }
+    return 0;
+}
 
-    bRet=sal_True;
+void SwView::ExecFieldPopup( const Point& rPt, IFieldmark *fieldBM )
+{
     const Point aPixPos = GetEditWin().LogicToPixel( rPt );
 
-    SwFieldDialog aFldDlg(pEditWin, fieldBM);
-    aFldDlg.SetPosPixel(pEditWin->OutputToScreenPixel(aPixPos));
+    mpFieldPopup = new SwFieldDialog( pEditWin, fieldBM );
+    mpFieldPopup->SetPopupModeEndHdl( LINK( this, SwView, FieldPopupModeEndHdl ) );
 
-    /*short ret=*/aFldDlg.Execute();
-    sal_Int32 selection=aFldDlg.getSelection();
-    if (selection>=0) {
-        (*fieldBM->GetParameters())[::rtl::OUString::createFromAscii(ODF_FORMDROPDOWN_RESULT)] = makeAny(selection);
-    }
-
-    pWrtShell->Pop( sal_False );
-    pWrtShell->LockView( bOldViewLock );
-
-    return bRet;
+    Rectangle aRect( pEditWin->OutputToScreenPixel( aPixPos ), Size( 0, 0 ) );
+    mpFieldPopup->StartPopupMode( aRect, FLOATWIN_POPUPMODE_DOWN|FLOATWIN_POPUPMODE_GRABFOCUS );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
